#############
API Reference
#############


*********
Class
*********

==============
Basic elements
==============

.. doxygenclass:: pyflowline::classes::vertex::pyvertex
    :members:

.. doxygenclass:: pyflowline::classes::edge::pyedge
    :members:

.. doxygenclass:: pyflowline::classes::flowline::pyflowline
    :members:



==============
Mesh cell
==============

.. doxygenclass:: pyflowline::classes::hexagon::pyhexagon
    :members:

.. doxygenclass:: pyflowline::classes::square::pysquare
    :members:

.. doxygenclass:: pyflowline::classes::latlon::pylatlon
    :members:

.. doxygenclass:: pyflowline::classes::mpas::pympas
    :members:

=====================
Others
=====================

.. doxygenclass:: pyflowline::classes::basin::pybasin
    :members:

.. doxygenclass:: pyflowline::classes::pycase::flowlinecase
    :members:

.. doxygenclass:: pyflowline::classes::confluence::pyconfluence
    :members:

.. doxygenclass:: pyflowline::classes::link::pycelllink
    :members:

